/// Base class for all exceptions in this library
abstract class MySQLException implements Exception {
  final String message;

  const MySQLException(this.message);

  String get _prefix;

  @override
  String toString() {
    return '$_prefix: $message';
  }
}

/// Class for errors generated by mysql server itself
///
/// Extends [MySQLException]. MySQL error code can be read from [errorCode]
class MySQLServerException extends MySQLException {
  /// MySQL server error code
  final int errorCode;

  const MySQLServerException(String message, this.errorCode) : super(message);

  @override
  String toString() {
    return '$_prefix [$errorCode]: $message';
  }

  @override
  String get _prefix => 'MySQLServerException';
}

/// Class for exceptions generated by this library
///
/// Extends [MySQLException]
class MySQLClientException extends MySQLException {
  const MySQLClientException(String message) : super(message);

  @override
  String get _prefix => 'MySQLClientException';
}

/// Class for mysql protocol specific exceptions
///
/// Extends [MySQLClientException]
class MySQLProtocolException extends MySQLClientException {
  const MySQLProtocolException(String message) : super(message);

  @override
  String get _prefix => 'MySQLProtocolException';
}
